Documentation
¶
Index ¶
- Variables
- func GetBuffer(rt *sobek.Runtime, value sobek.Value) ([]byte, bool)
- func IsBuffer(rt *sobek.Runtime, value sobek.Value) bool
- func NewBlob(rt *sobek.Runtime, data Reader, size int64, type_ string) sobek.Value
- func NewFile(rt *sobek.Runtime, r Reader, size int64, type_, name string, ...) sobek.Value
- func ReadAll(r io.ReaderAt) ([]byte, error)
- type Blob
- type Buffer
- type File
- type Reader
Constants ¶
This section is empty.
Variables ¶
var (
TypeBlob = reflect.TypeOf((*blob)(nil))
)
var TypeFile = reflect.TypeOf((*file)(nil))
Functions ¶
func GetBuffer ¶
GetBuffer returns the underlying byte buffer from a ArrayBuffer, TypedArray, DataView, Buffer.
Types ¶
type Blob ¶
type Blob struct{}
Blob interface represents a blob, which is a file-like object of immutable, raw data; they can be read as text or binary data, or converted into a ReadableStream so its methods can be used for processing the data. https://developer.mozilla.org/en-US/docs/Web/API/Blob
type Buffer ¶
type Buffer struct{}
Buffer used to represent a fixed-length sequence of bytes. https://nodejs.org/api/buffer.html#buffer
type File ¶
type File struct{}
File object is a specific kind of Blob, and can be used in any context that a Blob can. https://developer.mozilla.org/en-US/docs/Web/API/File
Click to show internal directories.
Click to hide internal directories.